@@ -46,6 +46,7 @@ Boston, MA 02110-1301, USA.
 #include <KTextEditor/AnnotationInterface>
 
 #include <sublime/area.h>
+#include <sublime/message.h>
 #include <sublime/view.h>
 #include <interfaces/iplugincontroller.h>
 #include <interfaces/iprojectcontroller.h>
@@ -85,7 +86,6 @@ public:
     explicit DocumentControllerPrivate(DocumentController* c)
         : controller(c)
         , fileOpenRecent(nullptr)
-        , globalTextEditorInstance(nullptr)
     {
     }
 
@@ -547,7 +547,6 @@ public:
     QPointer<QAction> closeAll;
     QPointer<QAction> closeAllOthers;
     KRecentFilesAction* fileOpenRecent;
-    KTextEditor::Document* globalTextEditorInstance;
 };
 Q_DECLARE_TYPEINFO(KDevelop::DocumentControllerPrivate::HistoryEntry, Q_MOVABLE_TYPE);
 
@@ -996,14 +995,14 @@ QString DocumentController::activeDocumentPath( const QString& target ) const
         }
     }
     IDocument* doc = activeDocument();
-    if(!doc || target == QStringLiteral("[selection]"))
+    if(!doc || target == QLatin1String("[selection]"))
     {
         Context* selection = ICore::self()->selectionController()->currentSelection();
         if(selection && selection->type() == Context::ProjectItemContext && !static_cast<ProjectItemContext*>(selection)->items().isEmpty())
         {
             QString ret = static_cast<ProjectItemContext*>(selection)->items().at(0)->path().pathOrUrl();
             if(static_cast<ProjectItemContext*>(selection)->items().at(0)->folder())
-                ret += QStringLiteral("/.");
+                ret += QLatin1String("/.");
             return  ret;
         }
         return QString();
@@ -1022,7 +1021,7 @@ QStringList DocumentController::activeDocumentPaths() const
         documents.insert(view->document()->documentSpecifier());
     }
 
-    return documents.toList();
+    return documents.values();
 }
 
 void DocumentController::registerDocumentForMimetype( const QString& mimetype,
@@ -1059,7 +1058,7 @@ QUrl DocumentController::nextEmptyDocumentUrl()
         if (DocumentController::isEmptyDocumentUrl(doc->url())) {
             const auto match = pattern.match(doc->url().toDisplayString(QUrl::PreferLocalFile));
             if (match.hasMatch()) {
-                const int num = match.captured(1).toInt();
+                const int num = match.capturedRef(1).toInt();
                 nextEmptyDocNumber = qMax(nextEmptyDocNumber, num + 1);
             } else {
                 nextEmptyDocNumber = qMax(nextEmptyDocNumber, 1);
@@ -1082,15 +1081,6 @@ IDocumentFactory* DocumentController::factory(const QString& mime) const
     return d->factories.value(mime);
 }
 
-KTextEditor::Document* DocumentController::globalTextEditorInstance()
-{
-    Q_D(DocumentController);
-
-    if(!d->globalTextEditorInstance)
-        d->globalTextEditorInstance = Core::self()->partControllerInternal()->createTextPart();
-    return d->globalTextEditorInstance;
-}
-
 bool DocumentController::openDocumentsSimple( QStringList urls )
 {
     Sublime::Area* area = Core::self()->uiControllerInternal()->activeArea();
@@ -1267,8 +1257,10 @@ void DocumentController::vcsAnnotateCurrentDocument()
         helper->annotation();
     }
     else {
-        KMessageBox::error(nullptr, i18n("Could not annotate the document because it is not "
-                                   "part of a version-controlled project."));
+        const QString messageText =
+            i18n("Could not annotate the document because it is not part of a version-controlled project.");
+        auto* message = new Sublime::Message(messageText, Sublime::Message::Error);
+        ICore::self()->uiController()->postMessage(message);
     }
 }
 
