@@ -100,7 +100,7 @@ void IdealController::addView(Qt::DockWidgetArea area, View* view)
     if (toolBarActions.isEmpty()) {
       dock->setWidget(w);
     } else {
-      QMainWindow *toolView = new QMainWindow();
+      auto* toolView = new QMainWindow();
       auto *toolBar = new QToolBar(toolView);
       int iconSize = m_mainWindow->style()->pixelMetric(QStyle::PM_SmallIconSize);
       toolBar->setIconSize(QSize(iconSize, iconSize));
@@ -185,9 +185,10 @@ void IdealController::dockLocationChanged(Qt::DockWidgetArea area)
         bar->showWidget(action, true);
 
         // the dock should now be the "last" opened in a new area, not in the old area
-        for (auto it = lastDockWidget.begin(); it != lastDockWidget.end(); ++it) {
-            if (it->data() == dock)
-                it->clear();
+        for (auto& dockWidgetPtr : lastDockWidget) {
+            if (dockWidgetPtr.data() == dock) {
+                dockWidgetPtr.clear();
+            }
         }
         lastDockWidget[area] = dock;
 
@@ -258,7 +259,7 @@ void IdealController::raiseView(View* view, RaiseMode mode)
 
 QList< IdealDockWidget* > IdealController::allDockWidgets() const
 {
-    return docks.toList();
+    return docks.values();
 }
 
 void IdealController::showDockWidget(IdealDockWidget* dock, bool show)
