@@ -34,6 +34,16 @@
 
 namespace KDevelop {
 
+using TextStreamFunction = QTextStream& (*)(QTextStream&);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+constexpr TextStreamFunction flush = Qt::flush;
+constexpr TextStreamFunction endl = Qt::endl;
+#else
+constexpr TextStreamFunction flush = ::flush;
+constexpr TextStreamFunction endl = ::endl;
+#endif
+
+
 bool askUser(const QString& mainText,
              const QString& ttyPrompt,
              const QString& mboxTitle,
@@ -50,9 +60,9 @@ bool askUser(const QString& mainText,
         QString input;
         forever {
             if (ttyDefaultToYes) {
-                out << QStringLiteral("%1: [Y/n] ").arg(ttyPrompt) << flush;
+                out << ttyPrompt << QLatin1String(": [Y/n] ") << flush;
             } else {
-                out << QStringLiteral("%1: [y/N] ").arg(ttyPrompt) << flush;
+                out << ttyPrompt << QLatin1String(": [y/N] ") << flush;
             }
             input = in.readLine().trimmed();
             if (input.isEmpty()) {
