@@ -27,7 +27,7 @@ namespace KDevMI { namespace MI {
 class MILexer;
 struct TokenStream;
 
-typedef void (MILexer::*scan_fun_ptr)(int *kind);
+using scan_fun_ptr = void (MILexer::*)(int*);
 
 struct Token
 {
@@ -44,6 +44,9 @@ struct FileSymbol
     inline FileSymbol() {}
 
     inline ~FileSymbol();
+
+private:
+    Q_DISABLE_COPY(FileSymbol)
 };
 
 struct TokenStream
